@@ -81,6 +81,11 @@ enum AnalyzerBits  { AN_0, AN_X, AN_Z, AN_1, AN_H, AN_U, AN_W, AN_L, AN_DASH, AN
 /* ^^^   Bit representation   ^^^ */
 
 
+#ifdef WAVE_USE_STRUCT_PACKING
+#pragma pack(push)
+#pragma pack(1)
+#endif
+
 typedef struct HistEnt
 {
 hptr next;	      /* next transition in history */
@@ -95,6 +100,11 @@ TimeType time;        /* time of transition */
 unsigned char flags;  /* so far only set on glitch/real condition */
 } HistEnt;
 
+#ifdef WAVE_USE_STRUCT_PACKING
+#pragma pack(pop)
+#endif
+
+
 enum HistEntFlagBits
 { HIST_GLITCH_B, HIST_REAL_B, HIST_STRING_B 
 };
@@ -108,6 +118,11 @@ enum HistEntFlagBits
 	#define HIST_STRING 0	/* for gcc -O2 optimization */
 #endif
 
+#ifdef WAVE_USE_STRUCT_PACKING
+#pragma pack(push)
+#pragma pack(1)
+#endif
+
 typedef struct VectorEnt
 {
 TimeType time;
@@ -115,6 +130,10 @@ vptr next;
 unsigned char v[1];
 } VectorEnt;
 
+#ifdef WAVE_USE_STRUCT_PACKING
+#pragma pack(pop)
+#endif
+
 
 #define MAX_HISTENT_TIME (~( (ULLDescriptor(-1)) << (sizeof(TimeType) * 8 - 1)))
 
@@ -134,6 +153,11 @@ int    actual;			/* bit number to be used in [] */
 int    refcnt;
 } ExpandReferences;
 
+#ifdef WAVE_USE_STRUCT_PACKING
+#pragma pack(push)
+#pragma pack(1)
+#endif
+
 struct Node
   {
     exptr    expansion; /* indicates which nptr this node was expanded from (if it was expanded at all) and (when implemented) refcnts */
@@ -154,12 +178,16 @@ struct Node
 
     int      numhist;	/* number of elements in the harray */
     unsigned int array_height, this_row;
-    unsigned char vartype; /* see nodeVarType, this is an internal value */
-    unsigned char vardir; /* see nodeVarDir, this is an internal value */
+    unsigned vardir : 2;  /* see nodeVarDir, this is an internal value (currently unused) */
+    unsigned vartype : 5; /* see nodeVarType, this is an internal value */
 
     unsigned extvals : 1; /* was formerly a pointer to ExtNode "ext", now simply a flag */
   };
 
+#ifdef WAVE_USE_STRUCT_PACKING
+#pragma pack(pop)
+#endif
+
 
 #define WAVE_NODEVARTYPE_STR \
 static const char *vartype_strings[] = { \
@@ -184,7 +212,8 @@ static const char *vartype_strings[] = { \
     "wor", \
     "array", \
     "realtime", \
-    "port" \
+    "port", \
+    "string" \
 };
 
 
@@ -213,10 +242,9 @@ enum nodeVarType {
     ND_VCD_REALTIME        = 20,
 
     ND_VCD_PORT		   = 21,
-    ND_VARTYPE_MAX	   = 21,
-                
-    ND_GEN_STRING          = 254,   /* generic string type */
-    ND_GEN_MEMBLOCK        = 255    /* generic memblock type */
+    ND_GEN_STRING          = 22,   /* generic string type */
+
+    ND_VARTYPE_MAX	   = 22
 };
 
 enum nodeVarDir {
@@ -448,8 +476,23 @@ void ClearGroupTraces(Trptr t);
 #endif
 
 /*
- * $Id: analyzer.h,v 1.30 2010/09/10 05:58:40 gtkwave Exp $
+ * $Id: analyzer.h,v 1.35 2010/12/18 23:56:50 gtkwave Exp $
  * $Log: analyzer.h,v $
+ * Revision 1.35  2010/12/18 23:56:50  gtkwave
+ * more structure rearrangement and packing
+ *
+ * Revision 1.34  2010/12/17 06:29:20  gtkwave
+ * Added --enable-struct-pack configure flag
+ *
+ * Revision 1.33  2010/12/09 15:28:59  gtkwave
+ * syntax typo fix
+ *
+ * Revision 1.32  2010/12/09 15:22:37  gtkwave
+ * remove unused memblock node type
+ *
+ * Revision 1.31  2010/12/09 15:19:16  gtkwave
+ * preliminary support for variable-length string datatype in FST
+ *
  * Revision 1.30  2010/09/10 05:58:40  gtkwave
  * structor reordering of VectorEnt to benefit 32-bit architectures
  *
