@@ -27,7 +27,9 @@
 # define _NO_PROTO
 #endif
 
+#if 0
 #define HAVE_CONFIG_H  /* needed for Wine */
+#endif
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -1283,8 +1285,21 @@ main (argc, argv)
 #endif /* TEST */
 
 /*
- * $Id: getopt.c,v 1.2 2007/04/20 02:08:11 gtkwave Exp $
+ * $Id: getopt.c,v 1.3 2007/08/26 21:35:40 gtkwave Exp $
  * $Log: getopt.c,v $
+ * Revision 1.3  2007/08/26 21:35:40  gtkwave
+ * integrated global context management from SystemOfCode2007 branch
+ *
+ * Revision 1.2.2.2  2007/08/06 03:50:46  gtkwave
+ * globals support for ae2, gtk1, cygwin, mingw.  also cleaned up some machine
+ * generated structs, etc.
+ *
+ * Revision 1.2  2007/06/01 00:05:35  gtkwave
+ * regenerated configure
+ *
+ * Revision 1.1.1.1  2007/05/30 04:27:54  gtkwave
+ * Imported sources
+ *
  * Revision 1.2  2007/04/20 02:08:11  gtkwave
  * initial release
  *
