@@ -57,25 +57,17 @@ if((!(*buf)[0])||(!fgets_rc))
 
 JRB vcd_ids = NULL;
 
-static unsigned int vcdid_hash(char *s)
+static unsigned int vcdid_hash(char *s, int len)
 {
-char *s2 = s;
 unsigned int val=0;
 int i;
-int len;
 
-while(*s2)
-	{
-	*s2 -=32;
-	s2++;
-	}
-
-len = s2 - s;
+s += len;
 
 for(i=0;i<len;i++)
         {
 	val *= 94;
-        val += (unsigned char)*(--s2);
+        val += ((unsigned char)*(--s)) - 32;
         }
 
 return(val);
@@ -215,6 +207,11 @@ while(!feof(f))
 					{
 					vartype = FST_VT_VCD_SUPPLY0;
 					}
+				else
+				if(!strcmp(st, "string"))		
+					{
+					vartype = FST_VT_GEN_STRING;
+					}
 				break;
 
 			case 't':
@@ -260,13 +257,15 @@ while(!feof(f))
 
 		st = strtok(NULL, " \t");
 		len = atoi(st);
-		if(vartype == FST_VT_VCD_PORT)
+		switch(vartype)
 			{
-			len = (len * 3) + 2;
+			case FST_VT_VCD_PORT: len = (len * 3) + 2; break;
+			case FST_VT_GEN_STRING: len = 0; break;
+			default: break;
 			}
 
 		st = strtok(NULL, " \t"); /* vcdid */
-		hash = vcdid_hash(st);
+		hash = vcdid_hash(st, strlen(st));
 
 		if(hash == (hash_max+1))
 			{
@@ -560,7 +559,7 @@ while(!feof(f))
 		case '1':
 		case 'x':
 		case 'z':
-			hash = vcdid_hash(buf+1);
+			hash = vcdid_hash(buf+1, nl - (buf+1));
 			if(!hash_kill)
 				{
 				fstWriterEmitValueChange(ctx, hash, buf);
@@ -581,7 +580,7 @@ while(!feof(f))
 		case 'b':
 			sp = strchr(buf, ' ');
 			*sp = 0;
-			hash = vcdid_hash(sp+1);
+			hash = vcdid_hash(sp+1, nl - (sp+1));
 			if(!hash_kill)
 				{
 				int bin_len = sp - (buf + 1); /* strlen(buf+1) */
@@ -624,6 +623,33 @@ while(!feof(f))
 				}
 			break;
 
+		case 's':
+			sp = strchr(buf, ' ');
+			*sp = 0;
+			hash = vcdid_hash(sp+1, nl - (sp+1));
+			if(!hash_kill)
+				{
+				int bin_len = sp - (buf + 1); /* strlen(buf+1) */
+
+				bin_len = fstUtilityEscToBin(NULL, (unsigned char *)(buf+1), bin_len);
+				fstWriterEmitVariableLengthValueChange(ctx, hash, buf+1, bin_len);
+				}
+				else
+				{
+				node = jrb_find_int(vcd_ids, hash);
+				if(node)
+					{
+					int bin_len = sp - (buf + 1); /* strlen(buf+1) */
+
+					bin_len = fstUtilityEscToBin(NULL, (unsigned char *)(buf+1), bin_len);
+					fstWriterEmitVariableLengthValueChange(ctx, node->val.i, buf+1, bin_len);
+					}
+					else
+					{
+					}
+				}
+			break;
+
 		case 'p':
 			{
 			char *src = buf+1;
@@ -647,7 +673,7 @@ while(!feof(f))
 			sp = strchr(sp+1, ' ');
 			sp = strchr(sp+1, ' ');
 			*sp = 0;
-			hash = vcdid_hash(sp+1);
+			hash = vcdid_hash(sp+1, nl - (sp+1));
 			if(!hash_kill)
 				{
 				fstWriterEmitValueChange(ctx, hash, bin_fixbuff);
@@ -668,7 +694,7 @@ while(!feof(f))
 
 		case 'r':
 			sp = strchr(buf, ' ');
-			hash = vcdid_hash(sp+1);
+			hash = vcdid_hash(sp+1, nl - (sp+1));
 			if(!hash_kill)
 				{
 		                sscanf(buf+1,"%lg",&doub); 
@@ -870,8 +896,20 @@ return(0);
 }
 
 /*
- * $Id: vcd2fst.c,v 1.16 2010/11/08 21:04:52 gtkwave Exp $
+ * $Id: vcd2fst.c,v 1.20 2010/12/19 07:59:10 gtkwave Exp $
  * $Log: vcd2fst.c,v $
+ * Revision 1.20  2010/12/19 07:59:10  gtkwave
+ * warnings fixes
+ *
+ * Revision 1.19  2010/12/14 19:30:21  gtkwave
+ * remove unnecessary string length check in hash algorithm
+ *
+ * Revision 1.18  2010/12/10 20:13:13  gtkwave
+ * added escape codes to string record parsing
+ *
+ * Revision 1.17  2010/12/09 15:19:16  gtkwave
+ * preliminary support for variable-length string datatype in FST
+ *
  * Revision 1.16  2010/11/08 21:04:52  gtkwave
  * optimize out strlen with direct calculation on "b" lines
  *
