@@ -33,7 +33,9 @@ extern "C" {
 #include <ctype.h>
 #include <errno.h>
 #include <unistd.h>
+#ifdef HAVE_INTTYPES_H
 #include <inttypes.h>
+#endif
 #include <zlib.h>
 #include <bzlib.h>
 #include <LzmaLib.h>
@@ -295,8 +297,11 @@ int 			vzt_wr_emit_value_bit_string(struct vzt_wr_trace *lt, struct vzt_wr_symbo
 #endif
 
 /*
- * $Id: vzt_write.h,v 1.3 2010/02/18 17:27:07 gtkwave Exp $
+ * $Id: vzt_write.h,v 1.4 2010/04/27 23:10:56 gtkwave Exp $
  * $Log: vzt_write.h,v $
+ * Revision 1.4  2010/04/27 23:10:56  gtkwave
+ * made inttype.h inclusion conditional
+ *
  * Revision 1.3  2010/02/18 17:27:07  gtkwave
  * extern "C" headers / version bump
  *
