@@ -21,11 +21,28 @@
 #include <signal.h>
 #include "debug.h"
 
+#if defined _MSC_VER || defined __MINGW32__
+#include <windows.h>
+#endif
+
+
 struct pipe_ctx
 {
+#if defined _MSC_VER || defined __MINGW32__
+
+HANDLE g_hChildStd_IN_Rd;
+HANDLE g_hChildStd_IN_Wr;  /* handle for gtkwave to write to */
+HANDLE g_hChildStd_OUT_Rd; /* handle for gtkwave to read from */
+HANDLE g_hChildStd_OUT_Wr;
+PROCESS_INFORMATION piProcInfo;
+
+#else
+
 FILE *sin, *sout;
 int fd0, fd1;
 pid_t pid;
+
+#endif
 };
 
 
@@ -35,8 +52,11 @@ void pipeio_destroy(struct pipe_ctx *p);
 #endif
 
 /*
- * $Id: pipeio.h,v 1.3 2009/09/14 03:00:08 gtkwave Exp $
+ * $Id: pipeio.h,v 1.4 2010/08/25 22:58:23 gtkwave Exp $
  * $Log: pipeio.h,v $
+ * Revision 1.4  2010/08/25 22:58:23  gtkwave
+ * added process file support for mingw
+ *
  * Revision 1.3  2009/09/14 03:00:08  gtkwave
  * bluespec code integration
  *
