@@ -112,7 +112,7 @@ while (*hay)
 	ht = hay; nt = needle;
 	while(*nt)
 		{
-		if(toupper(*(ht+offs)) != toupper(*nt)) break;
+		if(toupper((int)(unsigned char)*(ht+offs)) != toupper((int)(unsigned char)*nt)) break;
 		offs++;
 		nt++;
 		}
@@ -1711,8 +1711,11 @@ if(GLOBALS->strace_ctx->timearray)
 }
 
 /*
- * $Id: strace.c,v 1.22 2010/06/13 20:38:00 gtkwave Exp $
+ * $Id: strace.c,v 1.23 2010/10/02 18:58:55 gtkwave Exp $
  * $Log: strace.c,v $
+ * Revision 1.23  2010/10/02 18:58:55  gtkwave
+ * ctype.h compiler warning fixes (char vs int)
+ *
  * Revision 1.22  2010/06/13 20:38:00  gtkwave
  * added strace repeat count
  *
