@@ -36,6 +36,11 @@ typedef long off_t;
 #include <io.h>
 #endif
 
+#ifdef WAVE_USE_STRUCT_PACKING
+#pragma pack(push)
+#pragma pack(1)
+#endif
+
 struct fac
 {
 struct Node *working_node;
@@ -44,6 +49,10 @@ int msb, lsb, len;
 unsigned int flags;
 };
 
+#ifdef WAVE_USE_STRUCT_PACKING
+#pragma pack(pop)
+#endif
+
 
 struct symbol
 {
@@ -125,8 +134,11 @@ void destroy_s_selected(void);
 #endif
 
 /*
- * $Id: symbol.h,v 1.14 2010/04/27 23:10:56 gtkwave Exp $
+ * $Id: symbol.h,v 1.15 2010/12/17 06:29:20 gtkwave Exp $
  * $Log: symbol.h,v $
+ * Revision 1.15  2010/12/17 06:29:20  gtkwave
+ * Added --enable-struct-pack configure flag
+ *
  * Revision 1.14  2010/04/27 23:10:56  gtkwave
  * made inttype.h inclusion conditional
  *
