@@ -72,7 +72,7 @@ static char tclBackslash(const char* src, int* readPtr) {
 	case 't': result = 0x9; break;
 	case 'v': result = 0xb; break;
 	case 'x':
-	    if (isxdigit(p[1])) {
+	    if (isxdigit((int)(unsigned char)p[1])) {
 		char* end;
 
 		result = (char)strtoul(p+1, &end, 16);
@@ -95,15 +95,15 @@ static char tclBackslash(const char* src, int* readPtr) {
 	    break;
 	default:
 	    /* Check for an octal number \oo?o? */
-	    if (isdigit(*p)) {
+	    if (isdigit((int)(unsigned char)*p)) {
 		result = *p - '0';
 		p++;
-		if (!isdigit(*p)) break;
+		if (!isdigit((int)(unsigned char)*p)) break;
 
 		count = 3;
 		result = (result << 3) + (*p - '0');
 		p++;
-		if (!isdigit(*p)) break;
+		if (!isdigit((int)(unsigned char)*p)) break;
 
 		count = 4;
 		result = (result << 3) + (*p - '0');
@@ -153,7 +153,7 @@ static int tclFindElement(const char* list, const char** elementPtr,
      * Skim off leading white space and check for an opening brace or
      * quote.
      */
-    while (isspace(*list)) list++;
+    while (isspace((int)(unsigned char)*list)) list++;
 
     if (*list == '{') {			/* } */
 	openBraces = 1;
@@ -187,7 +187,7 @@ static int tclFindElement(const char* list, const char** elementPtr,
 		if (openBraces == 1) {
 		    size = p - list;
 		    p++;
-		    if (isspace(*p) || (*p == 0)) goto done;
+		    if (isspace((int)(unsigned char)*p) || (*p == 0)) goto done;
 
 		    /* list element in braces followed by garbage instead of
 		     * space
@@ -233,7 +233,7 @@ static int tclFindElement(const char* list, const char** elementPtr,
 		if (inQuotes) {
 		    size = p-list;
 		    p++;
-		    if (isspace(*p) || (*p == 0)) goto done;
+		    if (isspace((int)(unsigned char)*p) || (*p == 0)) goto done;
 
 		    /* list element in quotes followed by garbage instead of
 		     * space
@@ -256,7 +256,7 @@ static int tclFindElement(const char* list, const char** elementPtr,
     }
 
   done:
-    while (isspace(*p)) p++;
+    while (isspace((int)(unsigned char)*p)) p++;
 
     *elementPtr = list;
     *nextPtr = p;
@@ -329,7 +329,7 @@ char** zSplitTclList(const char* list, int* argcPtr) {
      * the number of space characters in the list.
      */
     for (size = 1, l = list; *l != 0; l++) {
-	if (isspace(*l)) size++;
+	if (isspace((int)(unsigned char)*l)) size++;
     }
     size++;				/* Leave space for final NULL */
 
@@ -811,7 +811,7 @@ if(elem)
 	pnt = s_new;
 	while(*pnt)
 		{
-		if( (!isalnum(*pnt)) && (!isspace(*pnt)) && (*pnt != GLOBALS->hier_delimeter) )
+		if( (!isalnum((int)(unsigned char)*pnt)) && (!isspace((int)(unsigned char)*pnt)) && (*pnt != GLOBALS->hier_delimeter) )
 			{
 			esc++;
 			}
@@ -825,7 +825,7 @@ if(elem)
 		pnt2 = s_new2;
 		while(*pnt)
 			{
-			if( (!isalnum(*pnt)) && (!isspace(*pnt)) && (*pnt != GLOBALS->hier_delimeter) )
+			if( (!isalnum((int)(unsigned char)*pnt)) && (!isspace((int)(unsigned char)*pnt)) && (*pnt != GLOBALS->hier_delimeter) )
 				{
 				*(pnt2++) = '\\';
 				}
@@ -2461,6 +2461,78 @@ return(is_url);
 
 #if defined(HAVE_LIBTCL)
 
+/* declare variables that will be shared with the repscript */
+#undef WAVE_TCLCB_M
+#define WAVE_TCLCB_M(a,b,c) a
+static const char *tclcb_var_names[] = { WAVE_TCLCB_MACRO_EXPANSION };
+
+#undef WAVE_TCLCB_M
+#define WAVE_TCLCB_M(a,b,c) b
+static const int tclcb_var_flags[] = { WAVE_TCLCB_MACRO_EXPANSION };
+
+#undef WAVE_TCLCB_M
+#define WAVE_TCLCB_M(a,b,c) c
+static const char *tclcb_var_inits[] = { WAVE_TCLCB_MACRO_EXPANSION };
+
+static void declare_tclcb_variables(Tcl_Interp *interp) 
+{
+int i = 0 ;
+while(tclcb_var_flags[i] != -1) 
+	{
+	gtkwavetcl_setvar(tclcb_var_names[i], tclcb_var_inits[i], tclcb_var_flags[i]) ;
+	i++;
+	}
+}
+
+
+static gboolean setvar_timer(gpointer arg)
+{
+static gboolean run_once = FALSE;
+
+if(run_once == FALSE) /* avoid any race conditions with the toolkit for uninitialized data */
+        {
+        run_once = TRUE;
+        return(TRUE);
+        }
+        else
+        {
+        static gboolean in_timer = FALSE;
+
+        if(!GLOBALS->busy_busy_c_1 && !in_timer)
+                {
+                Tcl_Interp *interp = (Tcl_Interp *)arg;
+                const char *tv = NULL;
+
+                in_timer = TRUE;
+                tv = Tcl_GetVar(interp, WAVE_TCLCB_TIMER_PERIOD, WAVE_TCLCB_TIMER_PERIOD_FLAGS);
+		if(tv)
+			{
+	                gtkwavetcl_setvar_nonblocking(WAVE_TCLCB_TIMER_PERIOD,tv,WAVE_TCLCB_TIMER_PERIOD_FLAGS);
+	                tv = Tcl_GetVar(interp, WAVE_TCLCB_TIMER_PERIOD, WAVE_TCLCB_TIMER_PERIOD_FLAGS);
+			}
+                in_timer = FALSE;
+
+		if(tv)
+			{
+	                g_timeout_add(atoi(tv), setvar_timer, arg);
+			}
+                return(FALSE);
+                }
+                else
+                {
+                return(TRUE);
+                }
+        }
+}
+
+
+static void init_setvar_timer(Tcl_Interp *interp)
+{
+g_timeout_add(atoi(WAVE_TCLCB_TIMER_PERIOD_INIT), setvar_timer, (gpointer)interp);
+}
+
+
+
 static int menu_func(ClientData clientData, Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[])
 {
 GtkItemFactoryEntry *ife = (GtkItemFactoryEntry *)clientData;
@@ -2468,6 +2540,31 @@ int i;
 struct wave_script_args *old_wave_script_args = GLOBALS->wave_script_args; /* stackable args */
 char fexit = GLOBALS->enable_fast_exit;
 
+if(GLOBALS->in_tcl_callback) /* don't allow callbacks to call menu functions (yet) */
+	{
+	char reportString[1024];
+	char menuItem[512];
+	Tcl_Obj *aobj;
+
+	char *src = ife->path;
+	char *dst = menuItem;
+
+	while(*src)
+		{
+		*dst = (*src != ' ') ? *src : '_';
+		src++;
+		dst++;
+		}
+	*dst = 0;
+
+	sprintf(reportString, "gtkwave::%s prohibited in callback", menuItem);
+	gtkwavetcl_setvar_nonblocking(WAVE_TCLCB_ERROR,reportString,WAVE_TCLCB_ERROR_FLAGS);
+
+	aobj = Tcl_NewStringObj(reportString, -1); 
+	Tcl_SetObjResult(interp, aobj);
+	return(TCL_ERROR);
+	}
+
 GLOBALS->wave_script_args = NULL;
 GLOBALS->enable_fast_exit = 1;
 
@@ -2524,6 +2621,47 @@ GLOBALS->wave_script_args = old_wave_script_args;
 return(TCL_OK); /* signal error with rc=TCL_ERROR, Tcl_Obj *aobj = Tcl_NewStringObj(reportString, -1); Tcl_SetObjResult(interp, aobj); */
 }
 
+/* XXXXXXXXXXXXXXXXXXXXXXXXX */
+/* XXX  RPC Tcl Variant  XXX */
+/* XXXXXXXXXXXXXXXXXXXXXXXXX */
+
+char *rpc_script_execute(const char *nam)
+{
+char *tpnt = NULL;
+char *s;
+
+if((nam) && (strlen(nam)) && (!GLOBALS->tcl_running))
+	{
+	int tclrc;
+	int nlen = strlen(nam);
+	char *tcl_cmd = wave_alloca(7 + nlen + 1);
+	strcpy(tcl_cmd, "source ");
+	strcpy(tcl_cmd+7, nam);
+
+	GLOBALS->tcl_running = 1;
+	tclrc = Tcl_Eval (GLOBALS->interp, tcl_cmd);
+	GLOBALS->tcl_running = 0;
+
+	if(tclrc != TCL_OK) 
+		{ 
+		tpnt = strdup_2(Tcl_GetStringResult (GLOBALS->interp)); 
+		}
+		else
+		{
+		tpnt = strdup_2("TCL_OK");
+		}
+	}
+
+if(!tpnt) tpnt = strdup_2("TCL_ERROR : no filename specified");
+
+s = malloc_2(strlen("--script ") + strlen(tpnt) + 1 + 1);
+sprintf(s, "%s%s\n", "--script ", tpnt);
+free_2(tpnt);
+
+return(s);
+}
+
+
 /* XXXXXXXXXXXXXXXXXXXXXXXXXXXXXX */
 /* XXX  Bluespec Tcl Variant  XXX */
 /* XXXXXXXXXXXXXXXXXXXXXXXXXXXXXX */
@@ -2531,7 +2669,7 @@ return(TCL_OK); /* signal error with rc=TCL_ERROR, Tcl_Obj *aobj = Tcl_NewString
 void gtkUpdate(ClientData ignore)
 {
   while (gtk_events_pending()) { gtk_main_iteration(); }
-  Tcl_CreateTimerHandler(0,gtkUpdate, (ClientData) NULL);
+  Tcl_CreateTimerHandler(50,gtkUpdate, (ClientData) NULL); /* ajb: was 0 period ...caused 100% CPU spike */
 }
 
 int  gtkwaveInterpreterInit(Tcl_Interp *interp) {
@@ -2579,6 +2717,8 @@ int  gtkwaveInterpreterInit(Tcl_Interp *interp) {
 			   (ClientData)NULL, (Tcl_CmdDeleteProc *)NULL);
     }
 
+  declare_tclcb_variables(interp) ;
+
   /* hide the "wish" window */
   Tcl_Eval(interp, "wm withdraw .");
 
@@ -2591,7 +2731,7 @@ int  gtkwaveInterpreterInit(Tcl_Interp *interp) {
     }
 
   Tcl_CreateTimerHandler(50,gtkUpdate, (ClientData) NULL);
-
+  init_setvar_timer(interp);
 
   return TCL_OK;
 }
@@ -2614,7 +2754,7 @@ if((GLOBALS->repscript_name) && (!GLOBALS->tcl_running))
 	{
 	int tclrc;
 	int nlen = strlen(GLOBALS->repscript_name);
-	char *tcl_cmd = malloc_2(7 + nlen + 1);
+	char *tcl_cmd = wave_alloca(7 + nlen + 1);
 	strcpy(tcl_cmd, "source ");
 	strcpy(tcl_cmd+7, GLOBALS->repscript_name);
 
@@ -2642,7 +2782,6 @@ if((GLOBALS->repscript_name) && (!GLOBALS->tcl_running))
 	if(tclrc != TCL_OK) { fprintf (stderr, "GTKWAVE | %s\n", Tcl_GetStringResult (GLOBALS->interp)); }
 #endif
 
-	free_2(tcl_cmd);
 	return(TRUE);
 	}
 	else
@@ -2724,6 +2863,8 @@ for (i = 0; gtkwave_commands[i].func != NULL; i++)
                 (ClientData)NULL, (Tcl_CmdDeleteProc *)NULL);
    	}
 
+declare_tclcb_variables(GLOBALS->interp);
+
 if(GLOBALS->repscript_name)
 	{
 	FILE *f = fopen(GLOBALS->repscript_name, "rb");
@@ -2739,8 +2880,38 @@ if(GLOBALS->repscript_name)
 		exit(255);
 		}
 	}
+
+init_setvar_timer(GLOBALS->interp);
 }
 
+
+/* blocking version which keeps recursive setvars from happening */
+const char *gtkwavetcl_setvar(const char *name1, const char *val, int flags)
+{
+const char *rc = NULL;
+if(GLOBALS->interp && !GLOBALS->in_tcl_callback)
+        {
+	GLOBALS->in_tcl_callback = 1;
+        rc = Tcl_SetVar(GLOBALS->interp, name1, val, flags);
+	GLOBALS->in_tcl_callback = 0;
+        }
+
+return(rc);
+}
+
+/* version which would be used, for example by timer interrupts */
+const char *gtkwavetcl_setvar_nonblocking(const char *name1, const char *val, int flags)
+{
+const char *rc = NULL;
+if(GLOBALS->interp)
+        {
+        rc = Tcl_SetVar(GLOBALS->interp, name1, val, flags);
+        }
+
+return(rc);
+}
+
+
 #else
 
 void make_tcl_interpreter(char *argv[])
@@ -2748,12 +2919,70 @@ void make_tcl_interpreter(char *argv[])
 /* nothing */
 }
 
+
+const char *gtkwavetcl_setvar(const char *name1, const char *val, int flags)
+{
+return(NULL);
+}
+
+
+const char *gtkwavetcl_setvar_nonblocking(const char *name1, const char *val, int flags)
+{
+return(NULL);
+}
+
+
+char *rpc_script_execute(const char *nam)
+{
+return(strdup_2("--script TCL_ERROR : Tcl support not compiled into gtkwave\n"));
+}
+
+
 #endif
 
 
 /*
- * $Id: tcl_helper.c,v 1.79 2010/07/15 14:27:05 gtkwave Exp $
+ * $Id: tcl_helper.c,v 1.93 2010/10/06 21:12:29 gtkwave Exp $
  * $Log: tcl_helper.c,v $
+ * Revision 1.93  2010/10/06 21:12:29  gtkwave
+ * fix for rpc_script_execute when tcl disabled
+ *
+ * Revision 1.92  2010/10/06 20:15:51  gtkwave
+ * preliminary version of RPC mechanism
+ *
+ * Revision 1.91  2010/10/02 18:58:55  gtkwave
+ * ctype.h compiler warning fixes (char vs int)
+ *
+ * Revision 1.90  2010/10/02 18:24:38  gtkwave
+ * warning fixes
+ *
+ * Revision 1.89  2010/08/18 15:21:17  gtkwave
+ * compile fix for when Tcl is disabled
+ *
+ * Revision 1.88  2010/08/02 17:27:04  gtkwave
+ * added tclcb variable init sequence
+ *
+ * Revision 1.86  2010/07/30 04:02:50  gtkwave
+ * fix for 0msec Tcl timer
+ *
+ * Revision 1.85  2010/07/28 19:56:27  gtkwave
+ * locking down callbacks from calling context changing events in viewer
+ *
+ * Revision 1.84  2010/07/27 22:52:16  gtkwave
+ * added nonblocking setvar (to be used only for well-known reasons)
+ *
+ * Revision 1.83  2010/07/27 07:22:46  gtkwave
+ * block tcl callbacks from calling menu functions (for now)
+ *
+ * Revision 1.82  2010/07/27 05:34:22  gtkwave
+ * add variable locking to prevent recursive tcl callbacks
+ *
+ * Revision 1.81  2010/07/27 05:01:45  gtkwave
+ * added gtkwavetcl_setvar for Tcl callback framework
+ *
+ * Revision 1.80  2010/07/26 15:32:44  gtkwave
+ * free_2 fix in repscript_times (possible context swap)
+ *
  * Revision 1.79  2010/07/15 14:27:05  gtkwave
  * repscript timer fix to print stack trace
  *
