@@ -160,8 +160,8 @@ s+=(len-1);
                  
 for(i=0;i<len;i++)
         {
-        val *= 95;				/* was 94 but XL uses '!' as right hand side chars which act as leading zeros */
-        val += (((unsigned char)*s) - 32);	/* was 33 but XL ... */
+        val *= 94;				
+        val += (((unsigned char)*s) - 32);
         s--;
         }
 
@@ -281,11 +281,11 @@ if(GLOBALS->numsyms_vcd_c_1)
 	{
         vcd_distance = GLOBALS->vcd_maxid_vcd_c_1 - GLOBALS->vcd_minid_vcd_c_1 + 1;
 
-        if(vcd_distance <= VCD_INDEXSIZ)
+        if((vcd_distance <= VCD_INDEXSIZ)||(!GLOBALS->vcd_hash_kill))
                 {
                 GLOBALS->indexed_vcd_c_1 = (struct vcdsymbol **)calloc_2(vcd_distance, sizeof(struct vcdsymbol *));
          
-		/* printf("%d symbols span ID range of %d, using indexing...\n", numsyms, vcd_distance); */
+		/* printf("%d symbols span ID range of %d, using indexing...\n", GLOBALS->numsyms_vcd_c_1, vcd_distance); */
 
                 v=GLOBALS->vcdsymroot_vcd_c_1;
                 while(v)
@@ -797,7 +797,7 @@ switch(GLOBALS->yytext_vcd_c_1[0])
 			}
 			else
 			{
-			if ((v->vartype==V_REAL)||((GLOBALS->convert_to_reals)&&((v->vartype==V_INTEGER)||(v->vartype==V_PARAMETER))))
+			if ((v->vartype==V_REAL)||(v->vartype==V_STRINGTYPE)||((GLOBALS->convert_to_reals)&&((v->vartype==V_INTEGER)||(v->vartype==V_PARAMETER))))
 				{
 				double *d;
 				char *pnt;
@@ -893,7 +893,7 @@ switch(GLOBALS->yytext_vcd_c_1[0])
 			}
 			else
 			{
-			if ((v->vartype==V_REAL)||((GLOBALS->convert_to_reals)&&((v->vartype==V_INTEGER)||(v->vartype==V_PARAMETER))))
+			if ((v->vartype==V_REAL)||(v->vartype==V_STRINGTYPE)||((GLOBALS->convert_to_reals)&&((v->vartype==V_INTEGER)||(v->vartype==V_PARAMETER))))
 				{
 				double *d;
 				char *pnt;
@@ -1001,8 +1001,12 @@ switch(GLOBALS->yytext_vcd_c_1[0])
 		char *d;
 
 		d=(char *)malloc_2(GLOBALS->yylen_vcd_c_1);
-		strcpy(d, GLOBALS->yytext_vcd_c_1+1);
-		
+		vlen = fstUtilityEscToBin((unsigned char *)d, (unsigned char *)(GLOBALS->yytext_vcd_c_1+1), GLOBALS->yylen_vcd_c_1); /* includes 0 term */
+		if(vlen != GLOBALS->yylen_vcd_c_1)
+			{
+			d = realloc_2(d, vlen);
+			}
+
 		get_strtoken();
 		v=bsearch_vcd(GLOBALS->yytext_vcd_c_1, GLOBALS->yylen_vcd_c_1);	
 		if(!v)
@@ -1216,7 +1220,7 @@ for(;;)
 				GLOBALS->varsplit_vcd_c_1=NULL;
 				}
 			vtok=get_vartoken(1);
-			if(vtok>V_PORT) goto bail;
+			if(vtok>V_STRINGTYPE) goto bail;
 
 			v=(struct vcdsymbol *)calloc_2(1,sizeof(struct vcdsymbol));
 			v->vartype=vtok;
@@ -1270,6 +1274,20 @@ for(;;)
 				strcpy(v->id, GLOBALS->yytext_vcd_c_1);
                                 v->nid=vcdid_hash(GLOBALS->yytext_vcd_c_1,GLOBALS->yylen_vcd_c_1);
 
+                                if(v->nid == (GLOBALS->vcd_hash_max+1))
+                                        {
+                                        GLOBALS->vcd_hash_max = v->nid;
+                                        }
+                                else
+                                if((v->nid>0)&&(v->nid<=GLOBALS->vcd_hash_max))
+                                        {
+                                        /* general case with aliases */
+                                        }
+                                else
+                                        {
+                                        GLOBALS->vcd_hash_kill = 1;
+                                        }
+
                                 if(v->nid < GLOBALS->vcd_minid_vcd_c_1) GLOBALS->vcd_minid_vcd_c_1 = v->nid;
                                 if(v->nid > GLOBALS->vcd_maxid_vcd_c_1) GLOBALS->vcd_maxid_vcd_c_1 = v->nid;
 
@@ -1347,6 +1365,20 @@ for(;;)
 				v->id=(char *)malloc_2(GLOBALS->yylen_vcd_c_1+1);
 				strcpy(v->id, GLOBALS->yytext_vcd_c_1);
                                 v->nid=vcdid_hash(GLOBALS->yytext_vcd_c_1,GLOBALS->yylen_vcd_c_1);
+
+                                if(v->nid == (GLOBALS->vcd_hash_max+1))
+                                        {
+                                        GLOBALS->vcd_hash_max = v->nid;
+                                        }
+                                else
+                                if((v->nid>0)&&(v->nid<=GLOBALS->vcd_hash_max))
+                                        {
+                                        /* general case with aliases */
+                                        }
+                                else
+                                        {
+                                        GLOBALS->vcd_hash_kill = 1;
+                                        }
                                 
                                 if(v->nid < GLOBALS->vcd_minid_vcd_c_1) GLOBALS->vcd_minid_vcd_c_1 = v->nid;
                                 if(v->nid > GLOBALS->vcd_maxid_vcd_c_1) GLOBALS->vcd_maxid_vcd_c_1 = v->nid;
@@ -1440,7 +1472,10 @@ for(;;)
                                 {
                                 if(v->vartype != V_EVENT)
                                         {
-                                        v->vartype = V_REAL;
+					if(v->vartype != V_STRINGTYPE)
+						{
+	                                        v->vartype = V_REAL;
+						}
                                         }
                                         else
                                         {
@@ -1449,9 +1484,12 @@ for(;;)
 
                                 } /* MTI fix */
 
-			if((v->vartype==V_REAL)||((GLOBALS->convert_to_reals)&&((v->vartype==V_INTEGER)||(v->vartype==V_PARAMETER))))
+			if((v->vartype==V_REAL)||(v->vartype==V_STRINGTYPE)||((GLOBALS->convert_to_reals)&&((v->vartype==V_INTEGER)||(v->vartype==V_PARAMETER))))
 				{
-				v->vartype=V_REAL;
+				if(v->vartype!=V_STRINGTYPE)
+					{
+					v->vartype=V_REAL;
+					}
 				v->size=1;		/* override any data we parsed in */
 				v->msi=v->lsi=0;
 				}
@@ -1549,7 +1587,7 @@ for(;;)
 				{
 				if(v->msi==v->lsi)
 					{
-					if(v->vartype==V_REAL)
+					if((v->vartype==V_REAL)||(v->vartype==V_STRINGTYPE))
 						{
 						fprintf(GLOBALS->vcd_save_handle,"%s\n",v->name);
 						}
@@ -1989,6 +2027,7 @@ switch(v->vartype)
         case V_WIRE:            nvt = ND_VCD_WIRE; break;
         case V_WOR:             nvt = ND_VCD_WOR; break;
         case V_PORT:            nvt = ND_VCD_PORT; break;
+	case V_STRINGTYPE:	nvt = ND_GEN_STRING; break;
         default:                nvt = ND_UNSPECIFIED_DEFAULT; break;
 	}
 n->vartype = nvt;
@@ -2006,7 +2045,7 @@ struct vcdsymbol *v;
 v=GLOBALS->vcdsymroot_vcd_c_1;
 while(v)
 	{
-	if(v->vartype==V_REAL)
+	if((v->vartype==V_REAL)||(v->vartype==V_STRINGTYPE))
 		{
 		double *d;
 
@@ -2031,7 +2070,7 @@ while(v)
 v=GLOBALS->vcdsymroot_vcd_c_1;
 while(v)
 	{
-	if(v->vartype==V_REAL)
+	if((v->vartype==V_REAL)||(v->vartype==V_STRINGTYPE))
 		{
 		double *d;
 
@@ -2105,7 +2144,7 @@ while(v)
 				}
 			}
 
-		if(((v->size==1)||(!GLOBALS->atomic_vectors))&&(v->vartype!=V_REAL))
+		if(((v->size==1)||(!GLOBALS->atomic_vectors))&&(v->vartype!=V_REAL)&&(v->vartype!=V_STRINGTYPE))
 			{
 			struct symbol *s = NULL;
 	
@@ -2197,7 +2236,7 @@ while(v)
 			}
 			else	/* atomic vector */
 			{
-			if(v->vartype!=V_REAL)
+			if((v->vartype!=V_REAL)&&(v->vartype!=V_STRINGTYPE))
 				{
 				sprintf(str+slen-1,"[%d:%d]",v->msi,v->lsi);
 				}
@@ -2617,8 +2656,23 @@ return(GLOBALS->max_time);
 /*******************************************************************************/
 
 /*
- * $Id: vcd.c,v 1.37 2010/11/19 06:47:16 gtkwave Exp $
+ * $Id: vcd.c,v 1.42 2010/12/19 07:59:10 gtkwave Exp $
  * $Log: vcd.c,v $
+ * Revision 1.42  2010/12/19 07:59:10  gtkwave
+ * warnings fixes
+ *
+ * Revision 1.41  2010/12/14 21:26:06  gtkwave
+ * support XL-style identifiers for optimization detection in sym build
+ *
+ * Revision 1.40  2010/12/14 19:53:14  gtkwave
+ * scaled back id multiplier from 95 to 94
+ *
+ * Revision 1.39  2010/12/12 18:32:45  gtkwave
+ * add "string" variable type to parsing of vcd variable declarations
+ *
+ * Revision 1.38  2010/12/10 20:13:13  gtkwave
+ * added escape codes to string record parsing
+ *
  * Revision 1.37  2010/11/19 06:47:16  gtkwave
  * use PJE0 macro for unuser error return on judy function calls
  *
