@@ -170,8 +170,8 @@ s+=(len-1);
                  
 for(i=0;i<len;i++)
         {
-        val *= 95;				/* was 94 but XL uses '!' as right hand side chars which act as leading zeros */
-        val += (((unsigned char)*s) - 32);	/* was 33 but XL ... */
+        val *= 94;
+        val += (((unsigned char)*s) - 32);
         s--;
         }
 
@@ -291,7 +291,7 @@ if(GLOBALS->numsyms_vcd_partial_c_2)
 	{
         vcd_distance = GLOBALS->vcd_maxid_vcd_partial_c_2 - GLOBALS->vcd_minid_vcd_partial_c_2 + 1;
 
-        if(vcd_distance <= VCD_INDEXSIZ)
+        if((vcd_distance <= VCD_INDEXSIZ)||(!GLOBALS->vcd_hash_kill))
                 {
                 GLOBALS->indexed_vcd_partial_c_2 = (struct vcdsymbol **)calloc_2(vcd_distance, sizeof(struct vcdsymbol *));
          
@@ -730,7 +730,7 @@ switch(GLOBALS->yytext_vcd_partial_c_2[0])
 			}
 			else
 			{
-			if ((v->vartype==V_REAL)||((GLOBALS->convert_to_reals)&&((v->vartype==V_INTEGER)||(v->vartype==V_PARAMETER))))
+			if ((v->vartype==V_REAL)||(v->vartype==V_STRINGTYPE)||((GLOBALS->convert_to_reals)&&((v->vartype==V_INTEGER)||(v->vartype==V_PARAMETER))))
 				{
 				double *d;
 				char *pnt;
@@ -839,7 +839,7 @@ switch(GLOBALS->yytext_vcd_partial_c_2[0])
 			}
 			else
 			{
-			if ((v->vartype==V_REAL)||((GLOBALS->convert_to_reals)&&((v->vartype==V_INTEGER)||(v->vartype==V_PARAMETER))))
+			if ((v->vartype==V_REAL)||(v->vartype==V_STRINGTYPE)||((GLOBALS->convert_to_reals)&&((v->vartype==V_INTEGER)||(v->vartype==V_PARAMETER))))
 				{
 				double *d;
 				char *pnt;
@@ -964,8 +964,12 @@ switch(GLOBALS->yytext_vcd_partial_c_2[0])
 		{
 		char *d;
 
-		d=(char *)malloc_2(GLOBALS->yylen_vcd_partial_c_2);
-		strcpy(d, GLOBALS->yytext_vcd_partial_c_2+1);
+                d=(char *)malloc_2(GLOBALS->yylen_vcd_partial_c_2);
+                vlen = fstUtilityEscToBin((unsigned char *)d, (unsigned char *)(GLOBALS->yytext_vcd_partial_c_2+1), GLOBALS->yylen_vcd_partial_c_2); /* includes 0 term */
+                if(vlen != GLOBALS->yylen_vcd_partial_c_2)
+                        {
+                        d = realloc_2(d, vlen);
+                        }
 		
 		get_strtoken();
 		v=bsearch_vcd(GLOBALS->yytext_vcd_partial_c_2, GLOBALS->yylen_vcd_partial_c_2);	
@@ -1182,7 +1186,7 @@ for(;;)
 				GLOBALS->varsplit_vcd_partial_c_2=NULL;
 				}
 			vtok=get_vartoken(1);
-			if(vtok>V_PORT) goto bail;
+			if(vtok>V_STRINGTYPE) goto bail;
 
 			v=(struct vcdsymbol *)calloc_2(1,sizeof(struct vcdsymbol));
 			v->vartype=vtok;
@@ -1236,6 +1240,20 @@ for(;;)
 				strcpy(v->id, GLOBALS->yytext_vcd_partial_c_2);
                                 v->nid=vcdid_hash(GLOBALS->yytext_vcd_partial_c_2,GLOBALS->yylen_vcd_partial_c_2);
 
+                                if(v->nid == (GLOBALS->vcd_hash_max+1))
+                                        {
+                                        GLOBALS->vcd_hash_max = v->nid;
+                                        }
+                                else
+                                if((v->nid>0)&&(v->nid<=GLOBALS->vcd_hash_max))
+                                        {
+                                        /* general case with aliases */
+                                        }
+                                else
+                                        {
+                                        GLOBALS->vcd_hash_kill = 1;
+                                        }
+
                                 if(v->nid < GLOBALS->vcd_minid_vcd_partial_c_2) GLOBALS->vcd_minid_vcd_partial_c_2 = v->nid;
                                 if(v->nid > GLOBALS->vcd_maxid_vcd_partial_c_2) GLOBALS->vcd_maxid_vcd_partial_c_2 = v->nid;
 
@@ -1313,6 +1331,20 @@ for(;;)
 				v->id=(char *)malloc_2(GLOBALS->yylen_vcd_partial_c_2+1);
 				strcpy(v->id, GLOBALS->yytext_vcd_partial_c_2);
                                 v->nid=vcdid_hash(GLOBALS->yytext_vcd_partial_c_2,GLOBALS->yylen_vcd_partial_c_2);
+
+                                if(v->nid == (GLOBALS->vcd_hash_max+1))
+                                        {
+                                        GLOBALS->vcd_hash_max = v->nid;
+                                        }
+                                else
+                                if((v->nid>0)&&(v->nid<=GLOBALS->vcd_hash_max))
+                                        {
+                                        /* general case with aliases */
+                                        }
+                                else
+                                        {
+                                        GLOBALS->vcd_hash_kill = 1;
+                                        }
                                 
                                 if(v->nid < GLOBALS->vcd_minid_vcd_partial_c_2) GLOBALS->vcd_minid_vcd_partial_c_2 = v->nid;
                                 if(v->nid > GLOBALS->vcd_maxid_vcd_partial_c_2) GLOBALS->vcd_maxid_vcd_partial_c_2 = v->nid;
@@ -1406,7 +1438,10 @@ for(;;)
                                 {
                                 if(v->vartype != V_EVENT)
                                         {
-                                        v->vartype = V_REAL;
+					if(v->vartype != V_STRINGTYPE)
+						{
+	                                        v->vartype = V_REAL;
+						}
                                         }
                                         else
                                         {
@@ -1415,9 +1450,12 @@ for(;;)
 
                                 } /* MTI fix */
 
-			if((v->vartype==V_REAL)||((GLOBALS->convert_to_reals)&&((v->vartype==V_INTEGER)||(v->vartype==V_PARAMETER))))
+			if((v->vartype==V_REAL)||(v->vartype==V_STRINGTYPE)||((GLOBALS->convert_to_reals)&&((v->vartype==V_INTEGER)||(v->vartype==V_PARAMETER))))
 				{
-				v->vartype=V_REAL;
+				if(v->vartype != V_STRINGTYPE)
+					{
+					v->vartype=V_REAL;
+					}
 				v->size=1;		/* override any data we parsed in */
 				v->msi=v->lsi=0;
 				}
@@ -1872,7 +1910,7 @@ hptr rc;
 v=GLOBALS->vcdsymroot_vcd_partial_c_2;
 while(v)
 	{
-	if(v->vartype==V_REAL)
+	if((v->vartype==V_REAL)||(v->vartype==V_STRINGTYPE))
 		{
 		double *d;
 
@@ -1906,7 +1944,7 @@ while(v)
 v=GLOBALS->vcdsymroot_vcd_partial_c_2;
 while(v)
 	{
-	if(v->vartype==V_REAL)
+	if((v->vartype==V_REAL)||(v->vartype==V_STRINGTYPE))
 		{
 		double *d;
 
@@ -1980,7 +2018,7 @@ while(v)
 				}
 			}
 
-		if(((v->size==1)||(!GLOBALS->atomic_vectors))&&(v->vartype!=V_REAL))
+		if(((v->size==1)||(!GLOBALS->atomic_vectors))&&(v->vartype!=V_REAL)&&(v->vartype!=V_STRINGTYPE))
 			{
 			struct symbol *s = NULL;
 	
@@ -2072,7 +2110,7 @@ while(v)
 			}
 			else	/* atomic vector */
 			{
-			if(v->vartype!=V_REAL)
+			if((v->vartype!=V_REAL)&&(v->vartype!=V_STRINGTYPE))
 				{
 				sprintf(str+slen-1,"[%d:%d]",v->msi,v->lsi);
 				}
@@ -2530,8 +2568,23 @@ gtkwave_main_iteration();
 }
 
 /*
- * $Id: vcd_partial.c,v 1.37 2010/11/19 06:47:16 gtkwave Exp $
+ * $Id: vcd_partial.c,v 1.42 2010/12/19 07:59:10 gtkwave Exp $
  * $Log: vcd_partial.c,v $
+ * Revision 1.42  2010/12/19 07:59:10  gtkwave
+ * warnings fixes
+ *
+ * Revision 1.41  2010/12/14 21:26:06  gtkwave
+ * support XL-style identifiers for optimization detection in sym build
+ *
+ * Revision 1.40  2010/12/14 19:53:14  gtkwave
+ * scaled back id multiplier from 95 to 94
+ *
+ * Revision 1.39  2010/12/12 18:32:45  gtkwave
+ * add "string" variable type to parsing of vcd variable declarations
+ *
+ * Revision 1.38  2010/12/10 20:13:13  gtkwave
+ * added escape codes to string record parsing
+ *
  * Revision 1.37  2010/11/19 06:47:16  gtkwave
  * use PJE0 macro for unuser error return on judy function calls
  *
