@@ -558,8 +558,8 @@ s+=(len-1);
                  
 for(i=0;i<len;i++)
         {
-        val *= 95;				/* was 94 but XL uses '!' as right hand side chars which act as leading zeros */
-        val += (((unsigned char)*s) - 32);	/* was 33 but XL ... */
+        val *= 94;
+        val += (((unsigned char)*s) - 32);
         s--;
         }
 
@@ -679,11 +679,11 @@ if(GLOBALS->numsyms_vcd_recoder_c_3)
 	{
         vcd_distance = GLOBALS->vcd_maxid_vcd_recoder_c_3 - GLOBALS->vcd_minid_vcd_recoder_c_3 + 1;
 
-        if(vcd_distance <= VCD_INDEXSIZ)
+        if((vcd_distance <= VCD_INDEXSIZ)||(!GLOBALS->vcd_hash_kill))
                 {
                 GLOBALS->indexed_vcd_recoder_c_3 = (struct vcdsymbol **)calloc_2(vcd_distance, sizeof(struct vcdsymbol *));
          
-		/* printf("%d symbols span ID range of %d, using indexing...\n", numsyms, vcd_distance); */
+		/* printf("%d symbols span ID range of %d, using indexing... hash_kill = %d\n", GLOBALS->numsyms_vcd_recoder_c_3, vcd_distance, GLOBALS->vcd_hash_kill);  */
 
                 v=GLOBALS->vcdsymroot_vcd_recoder_c_3;
                 while(v)
@@ -754,7 +754,7 @@ while(v)
 						vlist_emit_string(&n->mv.mvlfac_vlist, "NaN");
 						break;
 
-				case V_STRING:
+				case V_STRINGTYPE:
 						vlist_emit_uv32(&n->mv.mvlfac_vlist, 'S');
 		                                vlist_emit_uv32(&n->mv.mvlfac_vlist, (unsigned int)v->vartype);
 		                                vlist_emit_uv32(&n->mv.mvlfac_vlist, (unsigned int)v->size);
@@ -1233,14 +1233,20 @@ switch((typ = GLOBALS->yytext_vcd_recoder_c_3[0]))
                 break;
 
 	/* encode everything else literally as a time delta + a string */
+#ifndef STRICT_VCD_ONLY         
+        case 's':
+        case 'S':
+                vector=wave_alloca(GLOBALS->yylen_cache_vcd_recoder_c_3=GLOBALS->yylen_vcd_recoder_c_3);
+		vlen = fstUtilityEscToBin((unsigned char *)vector, (unsigned char *)(GLOBALS->yytext_vcd_recoder_c_3+1), GLOBALS->yylen_vcd_recoder_c_3-1); 
+		vector[vlen] = 0;                                        
+
+                get_strtoken();
+		goto process_binary;
+#endif                          
         case 'b':
         case 'B':
         case 'r':
         case 'R':
-#ifndef STRICT_VCD_ONLY         
-        case 's':
-        case 'S':
-#endif                          
                 vector=wave_alloca(GLOBALS->yylen_cache_vcd_recoder_c_3=GLOBALS->yylen_vcd_recoder_c_3);
                 strcpy(vector,GLOBALS->yytext_vcd_recoder_c_3+1); 
                 vlen=GLOBALS->yylen_vcd_recoder_c_3-1;
@@ -1263,7 +1269,7 @@ process_binary:
 				unsigned char typ2 = toupper(typ);
 				n->mv.mvlfac_vlist = (GLOBALS->vlist_prepack) ? ((struct vlist_t *)vlist_packer_create()) : vlist_create(sizeof(char));
 
-				if(v->vartype!=V_REAL) 
+				if((v->vartype!=V_REAL) && (v->vartype!=V_STRINGTYPE))
 					{
 					/* ok, typical case */
 					}
@@ -1288,7 +1294,7 @@ process_binary:
 
 			if((typ=='b')||(typ=='B'))
 				{
-				if(v->vartype!=V_REAL)
+				if((v->vartype!=V_REAL)&&(v->vartype!=V_STRINGTYPE))
 					{
 					vlist_emit_mvl9_string(&n->mv.mvlfac_vlist, vector);
 					}
@@ -1299,7 +1305,7 @@ process_binary:
 				}
 				else
 				{
-				if((v->vartype == V_REAL)||(typ=='s')||(typ=='S'))
+				if((v->vartype == V_REAL)||(v->vartype == V_STRINGTYPE)||(typ=='s')||(typ=='S'))
 					{
 					vlist_emit_string(&n->mv.mvlfac_vlist, vector);
 					}
@@ -1536,7 +1542,7 @@ for(;;)
                                 GLOBALS->varsplit_vcd_recoder_c_3=NULL;
                                 }
 			vtok=get_vartoken(1);
-			if(vtok>V_PORT) goto bail;
+			if(vtok>V_STRINGTYPE) goto bail;
 
 			v=(struct vcdsymbol *)calloc_2(1,sizeof(struct vcdsymbol));
 			v->vartype=vtok;
@@ -1590,6 +1596,20 @@ for(;;)
 				strcpy(v->id, GLOBALS->yytext_vcd_recoder_c_3);
                                 v->nid=vcdid_hash(GLOBALS->yytext_vcd_recoder_c_3,GLOBALS->yylen_vcd_recoder_c_3);
 
+		                if(v->nid == (GLOBALS->vcd_hash_max+1))
+                		        {
+		                        GLOBALS->vcd_hash_max = v->nid;
+		                        }
+		                else
+		                if((v->nid>0)&&(v->nid<=GLOBALS->vcd_hash_max))
+		                        {
+		                        /* general case with aliases */
+		                        }
+		                else
+		                        {
+		                        GLOBALS->vcd_hash_kill = 1;
+		                        }
+
                                 if(v->nid < GLOBALS->vcd_minid_vcd_recoder_c_3) GLOBALS->vcd_minid_vcd_recoder_c_3 = v->nid;
                                 if(v->nid > GLOBALS->vcd_maxid_vcd_recoder_c_3) GLOBALS->vcd_maxid_vcd_recoder_c_3 = v->nid;
 
@@ -1671,7 +1691,21 @@ for(;;)
 				v->id=(char *)malloc_2(GLOBALS->yylen_vcd_recoder_c_3+1);
 				strcpy(v->id, GLOBALS->yytext_vcd_recoder_c_3);
                                 v->nid=vcdid_hash(GLOBALS->yytext_vcd_recoder_c_3,GLOBALS->yylen_vcd_recoder_c_3);
-                                
+
+                                if(v->nid == (GLOBALS->vcd_hash_max+1))
+                                        {
+                                        GLOBALS->vcd_hash_max = v->nid;
+                                        }
+                                else
+                                if((v->nid>0)&&(v->nid<=GLOBALS->vcd_hash_max))
+                                        {
+                                        /* general case with aliases */
+                                        }
+                                else
+                                        {
+                                        GLOBALS->vcd_hash_kill = 1;
+                                        }
+
                                 if(v->nid < GLOBALS->vcd_minid_vcd_recoder_c_3) GLOBALS->vcd_minid_vcd_recoder_c_3 = v->nid;
                                 if(v->nid > GLOBALS->vcd_maxid_vcd_recoder_c_3) GLOBALS->vcd_maxid_vcd_recoder_c_3 = v->nid;
 
@@ -1768,7 +1802,10 @@ for(;;)
 				{ 
 				if(v->vartype != V_EVENT)
 					{
-					v->vartype = V_REAL; 
+					if(v->vartype != V_STRINGTYPE)
+						{
+						v->vartype = V_REAL; 
+						}
 					}
 					else
 					{
@@ -1777,9 +1814,9 @@ for(;;)
 
 				} /* MTI fix */
 
-			if(v->vartype==V_REAL)
+
+			if((v->vartype==V_REAL)||(v->vartype==V_STRINGTYPE))
 				{
-				v->vartype=V_REAL;
 				v->size=1;		/* override any data we parsed in */
 				v->msi=v->lsi=0;
 				}
@@ -1845,7 +1882,7 @@ for(;;)
 				{
 				if(v->msi==v->lsi)
 					{
-					if(v->vartype==V_REAL)
+					if((v->vartype==V_REAL)||(v->vartype==V_STRINGTYPE))
 						{
 						fprintf(GLOBALS->vcd_save_handle,"%s\n",v->name);
 						}
@@ -2333,7 +2370,7 @@ while(v)
 				}
 			}
 
-		if((v->size==1)&&(v->vartype!=V_REAL))
+		if((v->size==1)&&(v->vartype!=V_REAL)&&(v->vartype!=V_STRINGTYPE))
 			{
 			struct symbol *s = NULL;
 	
@@ -2426,7 +2463,7 @@ while(v)
 			}
 			else	/* atomic vector */
 			{
-			if(v->vartype!=V_REAL)
+			if((v->vartype!=V_REAL)&&(v->vartype!=V_STRINGTYPE))
 				{
 				sprintf(str+slen-1,"[%d:%d]",v->msi,v->lsi);
 				}
@@ -3233,8 +3270,23 @@ np->mv.mvlfac_vlist = NULL;
 }
 
 /*
- * $Id: vcd_recoder.c,v 1.47 2010/11/19 06:47:16 gtkwave Exp $
+ * $Id: vcd_recoder.c,v 1.52 2010/12/19 07:59:10 gtkwave Exp $
  * $Log: vcd_recoder.c,v $
+ * Revision 1.52  2010/12/19 07:59:10  gtkwave
+ * warnings fixes
+ *
+ * Revision 1.51  2010/12/14 21:26:06  gtkwave
+ * support XL-style identifiers for optimization detection in sym build
+ *
+ * Revision 1.50  2010/12/14 19:53:14  gtkwave
+ * scaled back id multiplier from 95 to 94
+ *
+ * Revision 1.49  2010/12/12 18:32:45  gtkwave
+ * add "string" variable type to parsing of vcd variable declarations
+ *
+ * Revision 1.48  2010/12/10 20:13:13  gtkwave
+ * added escape codes to string record parsing
+ *
  * Revision 1.47  2010/11/19 06:47:16  gtkwave
  * use PJE0 macro for unuser error return on judy function calls
  *
