@@ -564,7 +564,9 @@ for(i=0;i<nodecnt;i++)
 			}
 			else
 			{
-			w32redirect_fprintf(GLOBALS->f_vcd_saver_c_1, "$var real 1 %s %s $end\n", vcdid(GLOBALS->hp_vcd_saver_c_1[i]->val, export_typ), netname);
+			const char *typ = (GLOBALS->hp_vcd_saver_c_1[i]->flags & HIST_STRING) ? "string" : "real";
+			int tlen = (GLOBALS->hp_vcd_saver_c_1[i]->flags & HIST_STRING) ? 0 : 1;
+			w32redirect_fprintf(GLOBALS->f_vcd_saver_c_1, "$var %s %d %s %s $end\n", typ, tlen, vcdid(GLOBALS->hp_vcd_saver_c_1[i]->val, export_typ), netname);
 			}
 		}
 		else
@@ -673,7 +675,13 @@ for(;;)
 					}
 					else
 					{
-					w32redirect_fprintf(GLOBALS->f_vcd_saver_c_1, "s%s %s\n", vec, vcdid(GLOBALS->hp_vcd_saver_c_1[0]->val, export_typ));
+					int vec_slen = strlen(vec);
+					char *vec_escaped = malloc_2(vec_slen*4 + 1); /* worst case */
+					int vlen = fstUtilityBinToEsc((unsigned char *)vec_escaped, (unsigned char *)vec, vec_slen);
+
+					vec_escaped[vlen] = 0;
+					w32redirect_fprintf(GLOBALS->f_vcd_saver_c_1, "s%s %s\n", vec_escaped, vcdid(GLOBALS->hp_vcd_saver_c_1[0]->val, export_typ));
+					free_2(vec_escaped);
 					}
 				}
 				else
@@ -1542,8 +1550,17 @@ return(errno ? VCDSAV_FILE_ERROR : VCDSAV_OK);
 }
 
 /*
- * $Id: vcd_saver.c,v 1.19 2010/08/26 18:42:23 gtkwave Exp $
+ * $Id: vcd_saver.c,v 1.22 2010/12/19 07:59:10 gtkwave Exp $
  * $Log: vcd_saver.c,v $
+ * Revision 1.22  2010/12/19 07:59:10  gtkwave
+ * warnings fixes
+ *
+ * Revision 1.21  2010/12/12 18:32:45  gtkwave
+ * add "string" variable type to parsing of vcd variable declarations
+ *
+ * Revision 1.20  2010/12/10 20:13:13  gtkwave
+ * added escape codes to string record parsing
+ *
  * Revision 1.19  2010/08/26 18:42:23  gtkwave
  * added support for transaction filters in mingw
  *
